@@ -61,6 +61,8 @@ struct _EvViewAccessiblePrivate {
 	GtkScrollType idle_scroll;
 
 	gint previous_cursor_page;
+	gint start_page;
+	gint end_page;
 
 	GPtrArray *children;
 };
@@ -501,3 +503,67 @@ ev_view_accessible_get_relevant_page (EvViewAccessible *accessible)
 
 	return get_relevant_page (view);
 }
+
+void
+_transform_doc_rect_to_atk_rect (EvViewAccessible *accessible,
+				 gint              page,
+				 EvRectangle      *doc_rect,
+				 EvRectangle      *atk_rect,
+				 AtkCoordType      coord_type)
+{
+	EvView *view;
+	GdkRectangle view_rect;
+	GtkWidget *widget, *toplevel;
+	gint x_widget, y_widget;
+
+	view = EV_VIEW (gtk_accessible_get_widget (GTK_ACCESSIBLE (accessible)));
+	_ev_view_transform_doc_rect_to_view_rect (view, page, doc_rect, &view_rect);
+	view_rect.x -= view->scroll_x;
+	view_rect.y -= view->scroll_y;
+
+	widget = GTK_WIDGET (view);
+	toplevel = gtk_widget_get_toplevel (widget);
+	gtk_widget_translate_coordinates (widget, toplevel, 0, 0, &x_widget, &y_widget);
+	view_rect.x += x_widget;
+	view_rect.y += y_widget;
+
+	if (coord_type == ATK_XY_SCREEN) {
+		gint x_window, y_window;
+		gdk_window_get_origin (gtk_widget_get_window (toplevel), &x_window, &y_window);
+		view_rect.x += x_window;
+		view_rect.y += y_window;
+	}
+
+	atk_rect->x1 = view_rect.x;
+	atk_rect->y1 = view_rect.y;
+	atk_rect->x2 = view_rect.x + view_rect.width;
+	atk_rect->y2 = view_rect.y + view_rect.height;
+}
+
+void
+ev_view_accessible_set_page_range (EvViewAccessible *accessible,
+				   gint start,
+				   gint end)
+{
+	gint i;
+	AtkObject *page;
+
+	g_return_if_fail (EV_IS_VIEW_ACCESSIBLE (accessible));
+
+	for (i = accessible->priv->start_page; i <= accessible->priv->end_page; i++) {
+		if (i < start || i > end) {
+			page = g_ptr_array_index (accessible->priv->children, i);
+			atk_object_notify_state_change (page, ATK_STATE_SHOWING, FALSE);
+		}
+	}
+
+	for (i = start; i <= end; i++) {
+		if (i < accessible->priv->start_page || i > accessible->priv->end_page) {
+			page = g_ptr_array_index (accessible->priv->children, i);
+			atk_object_notify_state_change (page, ATK_STATE_SHOWING, TRUE);
+		}
+	}
+
+	accessible->priv->start_page = start;
+	accessible->priv->end_page = end;
+}
